classdef CostFunction < falcon.core.Handle & falcon.core.HasProblem
    % FALCON.PAREST.COSTFUNCTION.COSTFUNCTION parameter estimation cost
    %   function
    %  
    %  	<Description>
    %  	implementation of basic functionalities for parameter estimation
    %  	cost functions
    %  
    %  	<ChangeLog>
    %  	2017-12-19 - Ch. Goettlicher: commenting (-->EMT completion)
    %   2018-06-26 - Ch. Goettlicher: split cost function in parts for
    %   outputs, parameters and process noise

    % -------------------------------------------------------------------------
    %                                FALCON.m
    % Copyright (c) 2014-2019 Institute of Flight System Dynamics, TUM, Munich
    % Matthias Bittner, Matthias Rieck, Maximilian Richter,
    % Benedikt Grueter, Johannes Diepolder, Florian Schwaiger,
    % Patrick Piprek, and Florian Holzapfel
    % Downloading, using, copying, or modifying FALCON.m code constitutes an
    % agreement to ALL of the terms of the FALCON.m EULA.
    % -------------------------------------------------------------------------

    properties
        % indicate if cost function scaling is to be used
        ScalarScalingMode
        % update model plots every x iterations
        UpdatePlots
        % internal falcon.Cost object to store cost function in
        Cost
        % cost function part for outputs
        J_y
        % cost function part for process noise ==> joint parameter and
        % state estimation
        J_w
        % cost function part for parameters ==> Bayesian estimation
        J_p
        % array of experiments; link to experiments in parent problem
        Experiments
        % array of phases; link to phases in parent problem
        Phases
        % flag to indicate, if process noise inputs are to be used
        useProcNoiseInputs
    end

    methods
        function addParameterCost(obj, CostFunctionString)
        % ADDPARAMETERCOST add term for parameters
        %  
        %  	<Syntax>
        %  	addParameterCost( obj, CostFunctionString )
        %  
        %  	<Description>
        %  	add term in the cost function, that represents parameter
        %  	cost, i.e. using a Gaussian prior for Bayesian MAP
        %  	estimation
        %  
        %  	<Inputs>
        %  	>obj: the falcon.parest.costfunction.CostFunction object
        %  	>CostFunctionString: Cost-Function implementation to be
        %  	used for parameter cost as string, e.g. 'LeastSquares'
        %  
        %  	<ChangeLog>
        %  	2018-06-26 - Ch. Goettlicher: commenting
        end

        function addProcNoiseCost(obj, CostFunctionString)
        % ADDPROCNOISECOST add term for process noise
        %  
        %  	<Syntax>
        %  	addProcNoiseCost( obj, CostFunctionString )
        %  
        %  	<Description>
        %  	add term to the cost function, that punishes process noise
        %  	for joint parameter and state estimation
        %  
        %  	<Inputs>
        %  	>obj: the falcon.parest.costfunction.CostFunction object
        %  	>CostFunctionString: Cost-Function implementation to be
        %  	used for parameter cost as string, e.g. 'LeastSquares'
        %  
        %  	<ChangeLog>
        %  	2018-06-26 - Ch. Goettlicher: commenting
        end

        function obj = CostFunction()
        % COSTFUNCTION [constructor parameter estimation cost function
        %  
        %  	<Syntax>
        %  	[ obj ] = CostFunction()
        %  
        %  	<Description>
        %  	implementation of basic functionalities for parameter estimation
        %  	cost functions. Per default, no process noise and no
        %  	parameter cost are considered.
        %  
        %  	<Outputs>
        %  	>obj: the falcon.parest.costfunction.CostFunction object
        %  
        %  	<ChangeLog>
        %  	2017-12-19 - Ch. Goettlicher: commenting (-->EMT completion)
        %  	2018-06-26 - Ch. Goettlicher: split cost function in parts for
        %  	             outputs, parameters and process noise
        end

    end

end