classdef MaximumLikelihood_mod < falcon.parest.costfunction.CostFunction
    % FALCON.PAREST.COSTFUNCTION.MAXIMUMLIKELIHOOD_MOD modified maximum
    %   likelihood cost
    %  
    %  	<Description>
    %  	modified maximum likelihood cost function type; the only considered
    %  	cost is the determinant of the residual covariance matrix; see
    %  	Jategaonkar - "Flight Vehicle System Identification"
    %  
    %  	<ChangeLog>
    %  	2017-12-19 - Ch. Goettlicher: commenting (-->EMT completion)

    % -------------------------------------------------------------------------
    %                                FALCON.m
    % Copyright (c) 2014-2019 Institute of Flight System Dynamics, TUM, Munich
    % Matthias Bittner, Matthias Rieck, Maximilian Richter,
    % Benedikt Grueter, Johannes Diepolder, Florian Schwaiger,
    % Patrick Piprek, and Florian Holzapfel
    % Downloading, using, copying, or modifying FALCON.m code constitutes an
    % agreement to ALL of the terms of the FALCON.m EULA.
    % -------------------------------------------------------------------------

    properties
        % indicate if cost function scaling is to be used
        ScalarScalingMode
        % update model plots every x iterations
        UpdatePlots
        % internal falcon.Cost object to store cost function in
        Cost
        % cost function part for outputs
        J_y
        % cost function part for process noise ==> joint parameter and
        % state estimation
        J_w
        % cost function part for parameters ==> Bayesian estimation
        J_p
        % array of experiments; link to experiments in parent problem
        Experiments
        % array of phases; link to phases in parent problem
        Phases
        % flag to indicate, if process noise inputs are to be used
        useProcNoiseInputs
    end

    methods
        function obj = MaximumLikelihood_mod()
        % constructor
        %  
        % <Syntax>
        % obj = MaximumLikelihood_mod( )
        %  
        % <Description>
        % constructs a falcon.parest.costfunction.MaximumLikelihood
        % object
        % <Outputs>
        % > obj: object
        end

        function addParameterCost(obj, CostFunctionString)
        % ADDPARAMETERCOST add term for parameters
        %  
        %  	<Syntax>
        %  	addParameterCost( obj, CostFunctionString )
        %  
        %  	<Description>
        %  	add term in the cost function, that represents parameter
        %  	cost, i.e. using a Gaussian prior for Bayesian MAP
        %  	estimation
        %  
        %  	<Inputs>
        %  	>obj: the falcon.parest.costfunction.CostFunction object
        %  	>CostFunctionString: Cost-Function implementation to be
        %  	used for parameter cost as string, e.g. 'LeastSquares'
        %  
        %  	<ChangeLog>
        %  	2018-06-26 - Ch. Goettlicher: commenting
        end

        function addProcNoiseCost(obj, CostFunctionString)
        % ADDPROCNOISECOST add term for process noise
        %  
        %  	<Syntax>
        %  	addProcNoiseCost( obj, CostFunctionString )
        %  
        %  	<Description>
        %  	add term to the cost function, that punishes process noise
        %  	for joint parameter and state estimation
        %  
        %  	<Inputs>
        %  	>obj: the falcon.parest.costfunction.CostFunction object
        %  	>CostFunctionString: Cost-Function implementation to be
        %  	used for parameter cost as string, e.g. 'LeastSquares'
        %  
        %  	<ChangeLog>
        %  	2018-06-26 - Ch. Goettlicher: commenting
        end

    end

end