classdef (Abstract) Experiment < falcon.core.Handle
    % FALCON.PAREST.PLOT.EXPERIMENT plotting for experiments
    %  
    %  	<Description>
    %  	this class implements the plot functionalities for experiment data
    %  
    %  	<ChangeLog>
    %  	2017-12-19 - Ch. Goettlicher: commenting (-->EMT completion)
    %   2018-06-26 - Ch. Goettlicher: moved labels here

    % -------------------------------------------------------------------------
    %                                FALCON.m
    % Copyright (c) 2014-2019 Institute of Flight System Dynamics, TUM, Munich
    % Matthias Bittner, Matthias Rieck, Maximilian Richter,
    % Benedikt Grueter, Johannes Diepolder, Florian Schwaiger,
    % Patrick Piprek, and Florian Holzapfel
    % Downloading, using, copying, or modifying FALCON.m code constitutes an
    % agreement to ALL of the terms of the FALCON.m EULA.
    % -------------------------------------------------------------------------

    properties
        % falcon.parest.plot.Experiment/PlotCfg_state is a property.
        PlotCfg_state
        % default plot properties for measurements, can be adjusted to
        % customize plot; if several signals are to be plotted in one
        % subplot, the array elements define the appearance of the
        % individual lines
        PlotCfg_meas
        % default plot properties for model, can be adjusted to customize
        % plot
        PlotCfg_model
        % default plot properties for controls, can be adjusted to
        % customize plot
        PlotCfg_control
        % falcon.parest.plot.Experiment/PlotCfg_procNoise is a property.
        PlotCfg_procNoise
        % default label properties, can be adjusted to customize labels
        Label_Cfg
        % cell array of label names of the controls in the experiment
        ControlLabels
        % falcon.parest.plot.Experiment/ProcessNoiseLabels is a property.
        ProcessNoiseLabels
        % falcon.parest.plot.Experiment/StateLabels is a property.
        StateLabels
        % cell array of label name of the time in the experiment
        TimeLabel
        % cell array of label names of the measurements in the experiment
        MeasurementLabels
    end

    methods
        function setTimeLabel(obj, TimeLabel)
        % SETTIMELABELS set label name of time
        %  
        %   <Syntax>
        %   obj.setTimeLabel( TimeLabel )
        %  
        %   <Description>
        %   set the label of the time by passing a cell array of
        %   strings of proper size (1 by 1) to this function. If this
        %   method is called for an array of experiments, all of them
        %   obtain the same time label
        %  
        %   <Inputs>
        %   >TimeLabel: cell array of strings containing the label of
        %   the time
        %  
        %  	<ChangeLog>
        %   2017-12-12 - X. Fang: initial design
        %   2018-06-26 - Ch. Goettlicher: moved labels here
        end

        function setStateLabels(obj, StateLabels)
        % falcon.parest.plot.Experiment/setStateLabels is a function.
        %   setStateLabels(obj, StateLabels)
        end

        function setProcessNoiseLabels(obj, ProcessNoiseLabels)
        % falcon.parest.plot.Experiment/setProcessNoiseLabels is a function.
        %   setProcessNoiseLabels(obj, ProcessNoiseLabels)
        end

        function setMeasurementLabels(obj, MeasurementLabels)
        % SETMEASUREMENTLABELS set label names of measurements
        %  
        %   <Syntax>
        %   obj.setMeasurementLabels( MeasurementLabels )
        %  
        %   <Description>
        %   set the labels of the measurement signals by passing a cell
        %   array of strings of proper size to this function. If this
        %   method is called for an array of experiments, all of them
        %   obtain the same measurement labels
        %  
        %   <Inputs>
        %   >MeasurementLabels: cell array of strings containing the
        %   labels of the measurements
        %  
        %  	<ChangeLog>
        %   2017-12-12 - X. Fang: initial design
        %   2018-06-26 - Ch. Goettlicher: moved labels here
        end

        function setControlLabels(obj, ControlLabels)
        % SETCONTROLLABELS set label names of control inputs
        %  
        %   <Syntax>
        %   obj.setControlLabels( ControlLabels )
        %  
        %   <Description>
        %   set the names of the control signals by passing a cell
        %   array of strings of proper size to this function. If this
        %   method is called for an array of experiments, all of them
        %   obtain the same control input names
        %  
        %   <Inputs>
        %   >ControlLabels: cell array of strings containing the label
        %   of the control inputs
        %  
        %  	<ChangeLog>
        %   2017-12-12 - X. Fang: initial design
        %   2018-06-26 - Ch. Goettlicher: moved labels here
        end

        function updateStates(obj)
        % get y-limits for plots from all outputs and measurements
        end

        function updateProcessNoise(obj)
        % get y-limits for plots from all outputs and measurements
        end

        function updateModelOutput(obj)
        % UPDATEMODELOUTPUT update model output plots
        %  
        %  	<Syntax>
        %  	updateModelOutput( obj )
        %  
        %  	<Description>
        %  	updates the model output structs by adjusting the
        %  	corresponding .YData property of the plot objects. This is
        %  	faster than plotting the respective line anew and is mainly
        %  	used within the optimization iteration.
        %  
        %  	<Inputs>
        %  	>obj: the Experiment object
        %  
        %  	<ChangeLog>
        %  	2017-01-31 - Ch. Goettlicher: initial design
        %  	2017-12-19 - Ch. Goettlicher: commenting (-->EMT completion)
        end

        function plotUncertainties(obj, varargin)
        % falcon.parest.plot.Experiment/plotUncertainties is a function.
        %   plotUncertainties(obj, varargin)
        end

        function plotModelOutput(obj)
        % PLOTMODELOUTPUT plot model output
        %  
        %  	<Syntax>
        %  	plotModelOutput( obj )
        %  
        %  	<Description>
        %  	if a plot is associated with this experiment, plot Model
        %  	outputs, using the signals in
        %  	falcon.parest.plot.Experiment.OutputsToPlot and the plot
        %  	configuration of falcon.parest.plot.Experiment.PlotCfg_model.
        %  	the last model output plot will be updated during the
        %  	iteration, if the corresponding property
        %  	falcon.parest.Problem.CostFunction.UpdatePlots is set to a
        %  	value greater than 0
        %  
        %  	<Inputs>
        %  	>obj: the Experiment object
        %  
        %  	<ChangeLog>
        %  	2017-01-31 - Ch. Goettlicher: initial design
        %  	2017-12-19 - Ch. Goettlicher: commenting (-->EMT completion)
        %   2018-06-26 - Ch. Goettlicher: plot separation bars on top
        end

        function plotExperiment(obj, varargin)
        % plot this experiment
        %  
        %   <Syntax>
        %   obj.plotExperiment( )
        %   obj.plotExperiment( Outputs )
        %   obj.plotExperiment( Outputs, Controls, Tags )
        %   obj.plotExperiment( )
        %  
        %  	<Description>
        %  	plot the experiment data, i.e. measurements and controls.
        %  	Via the name-value pair input arguments, certain outputs
        %  	and controls can be selected for the plot, otherwise all
        %  	controls and measurements will be plotted. Also, certain
        %  	Tags can be chosen to be printed on top of the experiment
        %  	data. Per default none are shown.
        %  	The appearance of the plot can be configured via the fields
        %  	of the falcon.parest.plot.Experiment.PlotConfig struct If
        %  	the Outputs or Controls input is only a cell array of
        %  	strings with signal names, every signal is plotted in its
        %  	own subplot. Elements of this cell array of strings can be
        %  	replaced by cell array of strings, in which case the
        %  	respective signals will be plotted in the same subplot.
        %  	e.g. 'Controls', {{'xi_l_pos', 'xi_r_pos'}, 'zeta_pos'}
        %  	plots the signals xi_l_pos and xi_r_pos in one subplot,
        %  	wheras zeta_pos is plotted in its own subplot.
        %  
        %  	<Inputs>
        %  	>obj: the Experiment object
        %  
        %  	<NameValue>
        %  	>Outputs: cell array of output names, which are to be
        %  	included in the plot
        %  	>Controls: cell array of control names, which are to be
        %  	included in the plot
        %  
        %  	<ChangeLog>
        %  	2017-01-31 - Ch. Goettlicher: initial design
        %   2017-11-21 - Ch. Goettlicher: plot several lines together
        %  	2017-12-19 - Ch. Goettlicher: commenting (-->EMT completion)
        %   2018-06-26 - Ch. Goettlicher: include name-assert; adjusted
        %   label things
        end

        function hasPlotIdx = hasPlot(obj)
        % HASPLOT check of this experiment array is plotted
        %  
        %  	<Syntax>
        %  	[ hasPlotIdx ] = hasPlot( obj )
        %  
        %  	<Description>
        %  	return an array of indices, indicating if the respective
        %  	element in the experiment array is associated with any plots.
        %  	To do so, the size of the OutputFields and ControlFields
        %  	properties are checked
        %  
        %  	<Inputs>
        %  	>obj: the Experiment object
        %  
        %  	<Outputs>
        %  	>hasPlotIdx: returned array of indices of experiments, which
        %  	have plots associated with them.
        %  
        %  	<ChangeLog>
        %  	2017-01-31 - Ch. Goettlicher: initial design
        %  	2017-12-19 - Ch. Goettlicher: commenting (-->EMT completion)
        end

        function clearPlots(obj)
        % CLEARPLOTS clear all plots
        %  
        %  	<Syntax>
        %  	clearPlots( obj )
        %  
        %  	<Description>
        %  	clear output and control field properties
        %  
        %  	<Inputs>
        %  	>obj: the Experiment object
        %  
        %  	<ChangeLog>
        %  	2017-12-19 - Ch. Goettlicher: commenting (-->EMT completion)
        end

        function obj = Experiment()
        % FALCON.PAREST.PLOT.EXPERIMENT plotting for experiments
        %  
        %  	<Description>
        %  	this class implements the plot functionalities for experiment data
        %  
        %  	<ChangeLog>
        %  	2017-12-19 - Ch. Goettlicher: commenting (-->EMT completion)
        %   2018-06-26 - Ch. Goettlicher: moved labels here
        end

    end

end