classdef AnimateGrid < falcon.core.Handle
    % FALCON.TRIM.AUX.ANIMATEGRID animation grid object
    %  
    %  	<Description>
    %  	this class implements all functions necessary to show the animated
    %  	progress plot for a nD-trim grid
    %  
    %  	<ChangeLog>
    %  	2017-12-20 - Ch. Goettlicher: final commenting

    % -------------------------------------------------------------------------
    %                                FALCON.m
    % Copyright (c) 2014-2019 Institute of Flight System Dynamics, TUM, Munich
    % Matthias Bittner, Matthias Rieck, Maximilian Richter,
    % Benedikt Grueter, Johannes Diepolder, Florian Schwaiger,
    % Patrick Piprek, and Florian Holzapfel
    % Downloading, using, copying, or modifying FALCON.m code constitutes an
    % agreement to ALL of the terms of the FALCON.m EULA.
    % -------------------------------------------------------------------------

    properties
    end

    methods
        function flag = isValid(obj)
        % ISVALID check validity
        %  
        %  	<Syntax>
        %  	[ flag ] = isValid( obj )
        %  
        %  	<Description>
        %  	show, if this object is valid (if it is existent, and if
        %  	the associated figure handle still exists and is valid) or
        %  	not
        %  
        %  	<Inputs>
        %  	>obj: the AnimateGrid object
        %  
        %  	<Outputs>
        %  	>flag: flag indicating the 'validity' of the object
        %  
        %  	<ChangeLog>
        %  	2017-03-08 - Ch. Goettlicher: initial design
        %  	2017-12-20 - Ch. Goettlicher: final commenting
        end

        function delete(obj)
        % DELETE cleanup
        %  
        %  	<Syntax>
        %  	delete( obj )
        %  
        %  	<Description>
        %  	clean up, i.e. close figure
        %  
        %  	<Inputs>
        %  	>obj: the AnimateGrid object
        %  
        %  	<ChangeLog>
        %  	2017-03-08 - Ch. Goettlicher: initial design
        %  	2017-12-20 - Ch. Goettlicher: final commenting
        end

        function update(obj, CurrentIdx, InitialSolutionIdx)
        % UPDATE the progress plot
        %  
        %  	<Syntax>
        %  	update( obj, CurrentIdx, InitialSolutionIdx )
        %  
        %  	<Description>
        %   update the points that have been trimmed, are currently
        %   trimmed, are on the current boundary of the trimmed region
        %   and are used as initial guess
        %  
        %  	<Inputs>
        %  	>obj: 
        %  	>CurrentIdx: idx of grid point currently to be trimmed
        %  	>InitialSolutionIdx: initial solution for current trim point
        %  
        %  	<ChangeLog>
        %  	2017-03-08 - Ch. Goettlicher: initial design
        %  	2017-12-20 - Ch. Goettlicher: final commenting
        end

        function updateBorder(obj, BorderIdx)
        % UPDATEBORDER update the border illustration in the animation
        %  
        %  	<Syntax>
        %  	updateBorder( obj, BorderIdx )
        %  
        %  	<Description>
        %  	update the values of the plot of the current "border" of
        %  	the trimmed area.
        %  
        %  	<Inputs>
        %  	>obj: the AnimateGrid object
        %  	>BorderIdx: index of the trim points, that are currently
        %  	located on the 'border' of the trimmed area
        %  
        %  	<ChangeLog>
        %  	2017-10-31 - Ch. Goettlicher: initial design
        %  	2017-12-20 - Ch. Goettlicher: final commenting
        end

        function obj = AnimateGrid(States, Controls, Outputs, Parameters, Constraints)
        % ANIMATEGRID create animation grid object
        %  
        %  	<Syntax>
        %  	[ obj ] = AnimateGrid( States, Controls, Outputs, Parameters, Constraints )
        %  
        %  	<Description>
        %  	create an animation grid object, handling the animation of
        %  	the trim grid progress
        %  
        %  	<Inputs>
        %  	>States: State information
        %  	>Controls: Controls information
        %  	>Outputs: Outputs information
        %  	>Parameters: Parameters information
        %  	>Constraints: Constraints information
        %  
        %  	<Outputs>
        %  	>obj: the newly created object
        %  
        %  	<ChangeLog>
        %  	2017-03-08 - Ch. Goettlicher: initial design
        %  	2017-12-20 - Ch. Goettlicher: final commenting
        end

    end

end