classdef Waitbar < falcon.core.Handle
    % FALCON.TRIM.AUX.WAITBAR waitbar object
    %  
    %  	<Description>
    %  	wrapper class for the built-in waitbar function. Issues information
    %  	on estimated time, and takes care that only one waitbar window is
    %  	open, even if the computations are aborted.
    %  
    %  	<ChangeLog>
    %  	2017-12-20 - Ch. Goettlicher: final commenting

    % -------------------------------------------------------------------------
    %                                FALCON.m
    % Copyright (c) 2014-2019 Institute of Flight System Dynamics, TUM, Munich
    % Matthias Bittner, Matthias Rieck, Maximilian Richter,
    % Benedikt Grueter, Johannes Diepolder, Florian Schwaiger,
    % Patrick Piprek, and Florian Holzapfel
    % Downloading, using, copying, or modifying FALCON.m code constitutes an
    % agreement to ALL of the terms of the FALCON.m EULA.
    % -------------------------------------------------------------------------

    properties
    end

    methods
        function flag = isValid(obj)
        % ISVALID check validity
        %  
        %  	<Syntax>
        %  	[ flag ] = isValid( obj )
        %  
        %  	<Description>
        %  	check, if this object is valid, i.e. if it exists, and if the
        %  	corresponding window is still open
        %  
        %  	<Inputs>
        %  	>obj: the Waitbar object
        %  
        %  	<Outputs>
        %  	>flag: logical to indicate validity
        %  
        %  	<ChangeLog>
        %  	2017-03-14 - Ch. Goettlicher: initial design
        %  	2017-12-20 - Ch. Goettlicher: final commenting
        end

        function delete(obj)
        % DELETE waitbar
        %  
        %  	<Syntax>
        %  	delete( obj )
        %  
        %  	<Description>
        %  	make sure, that the waitbar figure is closed once this
        %  	obejct is deleted.
        %  
        %  	<Inputs>
        %  	>obj: the Waitbar object
        %  
        %  	<ChangeLog>
        %  	2017-03-14 - Ch. Goettlicher: initial design
        %  	2017-12-20 - Ch. Goettlicher: final commenting
        end

        function terminate(obj)
        % TERMINATE terminate waitbar
        %  
        %  	<Syntax>
        %  	terminate( obj )
        %  
        %  	<Description>
        %  	terminate the waitbar, i.e. print message to command
        %  	window, how long the iteration took and close the waitbar
        %  	figure.
        %  
        %  	<Inputs>
        %  	>obj: the Waitbar object
        %  
        %  	<ChangeLog>
        %  	2017-03-14 - Ch. Goettlicher: initial design
        %  	2017-12-20 - Ch. Goettlicher: final commenting
        end

        function update(obj, Count)
        % UPDATE waitbar
        %  
        %  	<Syntax>
        %  	update( obj, Count )
        %  
        %  	<Description>
        %  	update the waitbar using the current index in the
        %  	iteration. From the time, since the last call to this
        %  	method, a time estimate is extrapolated for the rest of the
        %  	iteration loop. this method is to be called in the
        %  	beginning of the iteration loop.
        %  
        %  	<Inputs>
        %  	>obj: the Waitbar object
        %  	>Count: current iteration index
        %  
        %  	<ChangeLog>
        %  	2017-03-14 - Ch. Goettlicher: initial design
        %  	2017-11-09 - Ch. Goettlicher: update for new trim strategy
        %  	2017-12-20 - Ch. Goettlicher: final commenting
        end

        function obj = Waitbar(nIter, varargin)
        % WAITBAR consruct waitbar object
        %  
        %   <Syntax>
        %   obj = Waitbar( nIter )
        %   obj = Waitbar( nIter, String )
        %  
        %  	<Description>
        %  	construct a waitbar object from the total number of
        %  	iterations to perform, together with an optional string to
        %  	print in the waitbar dialog
        %  
        %  	<Inputs>
        %  	>nIter: total number of iterations to perform
        %  
        %  	<NameValue>
        %  	>String: string to print in waitbar
        %  
        %  	<Outputs>
        %  	>obj: the newly created waitbar object
        %  
        %  	<ChangeLog>
        %  	2017-03-14 - Ch. Goettlicher: initial design
        %  	2017-12-20 - Ch. Goettlicher: final commenting
        end

    end

end