classdef Linearizer < falcon.core.Handle & falcon.trim.core.HasTrimProblem
    % FALCON.TRIM.LINEARIZER linearization of non-linear models
    %  
    %  	<Description>
    %  	Interface to compute linearizations by evaluating the falcon
    %  	Simulation-Model-Builder model, and extracting the relevant
    %  	sub-matrices to build a linear, time-invariant state-space system.
    %  
    %  	<ChangeLog>
    %  	2017-12-20 - Ch. Goettlicher: final commenting

    % -------------------------------------------------------------------------
    %                                FALCON.m
    % Copyright (c) 2014-2019 Institute of Flight System Dynamics, TUM, Munich
    % Matthias Bittner, Matthias Rieck, Maximilian Richter,
    % Benedikt Grueter, Johannes Diepolder, Florian Schwaiger,
    % Patrick Piprek, and Florian Holzapfel
    % Downloading, using, copying, or modifying FALCON.m code constitutes an
    % agreement to ALL of the terms of the FALCON.m EULA.
    % -------------------------------------------------------------------------

    properties
    end

    methods
        function resObj = linearize(obj, varargin)
        % LINEARIZE extract linearization information from trim problem
        %  
        %  	<Syntax>
        %   resObj = obj.linearize( )
        %   resObj = obj.linearize( 'States', States )
        %   resObj = obj.linearize( 'Inputs', Inputs )
        %   resObj = obj.linearize( 'Outputs', Outputs )
        %  
        %  	<Description>
        %  	call model at trim points and extract linearization
        %  	information from jacobians. Name Value pairs can be used to
        %  	extract sub-systems from the overall linear system
        %  
        %  	<Inputs>
        %  	>obj: 
        %  	>varargin: 
        %  
        %  	<NameValue>
        %  	>States: cell array of state name strings to extract
        %  	sub-systems
        %  	>Inputs: cell array of input name strings to extract
        %  	sub-systems
        %  	>Outputs: cell array of output name strings to extract
        %  	sub-systems
        %  
        %  	<Outputs>
        %  	>resObj: object containing the linearization results
        %  
        %  	<ChangeLog>
        %  	2017-03-08 - Ch. Goettlicher: initial design
        %  	2017-12-20 - Ch. Goettlicher: final commenting
        end

        function obj = Linearizer(TrimProblem)
        % LINEARIZER constructor
        %  
        %  	<Syntax>
        %  	[ obj ] = Linearizer( obj )
        %  
        %  	<Description>
        %  	constructor, setting the TrimProblem
        %  
        %  	<Inputs>
        %  	>TrimProblem: the (trimmed) trim problem
        %  
        %  	<Outputs>
        %  	>obj: 
        %  
        %  	<ChangeLog>
        %  	2017-03-08 - Ch. Goettlicher: initial design
        %  	2017-12-20 - Ch. Goettlicher: final commenting
        end

        function setTrimProblem(obj, TrimProblem)
        % SETTRIMPROBLEM set the trim problem
        %  
        %  	<Syntax>
        %  	setTrimProblem( obj, TrimProblem )
        %  
        %  	<Description>
        %  	set reference to a trim problem handle
        %  
        %  	<Inputs>
        %  	>obj: the HasTrimProblem object
        %  	>TrimProblem: the trim problem
        %  
        %  	<ChangeLog>
        %  	2016-12-15 - Ch. Goettlicher: initial version
        %  	2017-02-07 - Ch. Goettlicher: commenting
        %  	2017-12-20 - Ch. Goettlicher: final commenting
        end

    end

end