%% Create the figure
figure1 = figure('Color',[1 1 1]);

%% Extract the trajectory data
distance     = cell(3,1);
height       = cell(3,1);
for iP=1:length(myProblem.Phases)
    distance{iP} = [distance{iP}, myProblem.Phases(iP).StateGrid.Values(4,:)];
    height{iP}   = [height{iP},   myProblem.Phases(iP).StateGrid.Values(3,:)];
end

%% Calculate the points for the mountain
s_mountain = distance{1}(1):1/length(tau):distance{3}(end);
h_mountain = (0.0.*s_mountain+40).*(0.5.*tanh(0.1.*(s_mountain-55))+0.5).*(0.5.*tanh(-(0.7.*s_mountain-70))+0.5)-0.3;

%% Draw the lines
hMountain = line(s_mountain, h_mountain);
hFalconStart  = line(distance{1}(1),  height{1}(1));
hFalconFinish = line(distance{3}(end),height{3}(end));

hData1   = line(distance{1},height{1});
hData2   = line(distance{2},height{2});
hData3   = line(distance{3},height{3});
hNest    = line(90,39.66);
hPrey    = line(30,0.0);

%% Style everything
% Start and finish markers
set(hFalconStart,...
    'Marker',            '.',...
    'LineStyle',         'none',...
    'MarkerSize',        25,...
    'Color',             [1 0 0]);
set(hFalconFinish,...
    'Marker',            '.',...
    'LineStyle',         'none',...
    'MarkerSize',        25,...
    'Color',             [0 1 0 ]);

% Trajectory lines
set(hData1,...
    'LineStyle',         '-',...
    'LineWidth',         3,...
    'Marker',            'none',...
    'Color',             [1 0 0]);

set(hData2,...
    'LineStyle',         '-',...
    'LineWidth',         3,...
    'Marker',            'none',...
    'Color',             [1 0.8 0 ]);

set(hData3,...
    'LineStyle',         '-',...
    'LineWidth',         3,...
    'Marker',            'none',...
    'Color',             [0.0 1 0.0]);

% Mountain line
set(hMountain,...
    'LineStyle',         '-',...
    'LineWidth',         3,...
    'Marker',            'none',...
    'Color',             [0.4 0.4 0.4]);

% Nest and prey
set(hNest,...
    'LineStyle',         'none',...
    'LineWidth',         3,...
    'Marker',            'x',...
    'MarkerSize',        8,...
    'Color',             [0 0 0]);

set(hPrey,...
    'LineStyle',         'none',...
    'LineWidth',         3,...
    'Marker',            '+',...
    'MarkerSize',        9,...
    'Color',             [0 0 0]);

% Labels
hXLabel = xlabel('distance [m]',...
    'fontweight','bold',...
    'Interpreter','Tex');
hYLabel = ylabel('height [m]',...
    'fontweight','bold',...
    'Interpreter','Tex');

% Legend
hLegend = legend( [hFalconStart,hFalconFinish,hData1,hData2,hData3,hNest,hPrey,hMountain], ...
    'Falcon: Initial Position',...
    'Falcon: Final Position',...
    'Falcon - Phase 1: Attack',...
    'Falcon - Phase 2: Delivery',...
    'Falcon - Phase 3: Return to Patrol',...
    'Nest',...
    'Prey',...
    'Ground',...
    'Location', 'northeastoutside',...
    'Orientation','vertical');
legend boxon
legend('show')

% Format
grid on
xlim([0 140])
ylim([-.5 50])
set(figure1, 'units', 'normalized', 'outerposition', [0 0 1 1]);