% build lateral aircraft model using simulation model builder from falcon.m

clear mex

falcon.init();

% model name
ModelName = 'B777Lat';

% get paths
currentDirectory = pwd();
ModelDirectory = fileparts(mfilename('fullpath'));
cd(ModelDirectory);

%% define states / controls / parameters / outputs
states   = [...
    falcon.State('r');
    falcon.State('beta');
    falcon.State('p');
    falcon.State('phi');
    ];

controls = [...
    falcon.Control('xi');
    falcon.Control('zeta');
    ];

parameters = [...
    falcon.Parameter('N_r');...
    falcon.Parameter('N_beta');...
    falcon.Parameter('N_p');...
    falcon.Parameter('N_xi');...
    falcon.Parameter('N_zeta');...
    falcon.Parameter('Y_r');...
    falcon.Parameter('Y_beta');...
    falcon.Parameter('Y_p');...
    falcon.Parameter('Y_xi');...
    falcon.Parameter('Y_zeta');...
    falcon.Parameter('L_r');...
    falcon.Parameter('L_beta');...
    falcon.Parameter('L_p');...
    falcon.Parameter('L_xi');...
    falcon.Parameter('L_zeta');...
    ];

outputs = [...
    falcon.Output('y_r'); ...
    falcon.Output('y_beta'); ...
    falcon.Output('y_p'); ...
    falcon.Output('y_phi'); ...
    ];

%% initialize model
mdl_build = falcon.parest.SimulationModelBuilder(...
    ModelName, ...
    states, ...
    controls, ...
    parameters, ...
    'Optimize', true, ...
    'DoDependencyCheck', false);

mdl_build.setOutputs( outputs );

mdl_build.setStateDerivativeNames({...
    'r_dot', ...
    'beta_dot'...
    'p_dot'...
    'phi_dot'});

%% add dynamics
mdl_build.addSubsystem(B777LatSystemDynamic,...
    'Outputs',{'r_dot', 'beta_dot', 'p_dot', 'phi_dot'},...
    'Inputs', {'r', 'beta', 'p', 'phi', ...
    'xi', 'zeta', ...
    'N_r', 'N_beta', 'N_p', 'N_xi', 'N_zeta', 'Y_r', 'Y_beta', 'Y_p', 'Y_xi', 'Y_zeta', 'L_r', 'L_beta', 'L_p', 'L_xi', 'L_zeta'});

%% add outputs
mdl_build.addSubsystem(B777LatOutput, ...
    'Outputs',{'y_r', 'y_beta', 'y_p', 'y_phi'},...
    'Inputs', {'r', 'beta', 'p', 'phi', ...
    'xi', 'zeta', ...
    'N_r', 'N_beta', 'N_p', 'N_xi', 'N_zeta', 'Y_r', 'Y_beta', 'Y_p', 'Y_xi', 'Y_zeta', 'L_r', 'L_beta', 'L_p', 'L_xi', 'L_zeta'});

%% compile model

mdl_build.Build('EvaluationProvider', 'mex');

cd(currentDirectory)