% build pt2 model using simulation model builder from falcon.m

clear mex

falcon.init();

% model name
ModelName = 'Pt2';

% get paths
currentDirectory = pwd();
ModelDirectory = fileparts(mfilename('fullpath'));
cd(ModelDirectory);

%% define states / controls / parameters / outputs
states   = [...
    falcon.State('x');
    falcon.State('v');
    ];

controls = [...
    falcon.Control('x_cmd');
    ];

parameters = [...
    falcon.Parameter('omega_0');...
    falcon.Parameter('zeta');
    falcon.Parameter('K');
    falcon.Parameter('C1');
    falcon.Parameter('C2');
    ];

outputs = [...
    falcon.Output('y1'); ...
    falcon.Output('y2'); ...
    ];

%% initialize model
mdl_build = falcon.parest.SimulationModelBuilder(...
    ModelName, ...
    states, ...
    controls, ...
    parameters, ...
    'Optimize', true, ...
    'DoDependencyCheck', false);

mdl_build.setOutputs( outputs );

mdl_build.setStateDerivativeNames({...
    'x_dot', ...
    'v_dot'});

%% add dynamics
mdl_build.addSubsystem(Pt2SystemDynamic,...
    'Outputs',{'x_dot', 'v_dot'},...
    'Inputs', {'x', 'v', 'x_cmd', 'omega_0', 'zeta', 'K'});

%% add outputs
mdl_build.addSubsystem(Pt2Output, ...
    'Outputs',{'y1', 'y2'},...
    'Inputs', {'x', 'v', 'omega_0', 'zeta', 'C1', 'C2'});

%% compile model

mdl_build.Build('EvaluationProvider', 'mex', ...
    'buildFilter', true);

cd(currentDirectory)